BubbleOptions class

Holds the bubbles configuration information for a BubblesBehaviour.

Constructors

BubbleOptions({int bubbleCount = 20, double minTargetRadius = 15.0, double maxTargetRadius = 50.0, double growthRate = 10.0, double popRate = 150.0})
Creates a BubbleOptions given a set of preferred values.
const

Properties

bubbleCount → int
The total count of bubbles that should be spawned.
final
growthRate → double
The growth rate of the bubbles.
final
hashCode → int
The hash code for this object.
no setterinherited
maxTargetRadius → double
The maximum radius a bubble should grow to.
final
minTargetRadius → double
The minimum radius a bubble should grow to before popping.
final
popRate → double
The pop rate of the bubbles.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? bubbleCount, double? minTargetRadius, double? maxTargetRadius, double? growthRate, double? popRate}) → BubbleOptions
Creates a copy of this BubbleOptions but with the given fields replaced with new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited