BubblesBehaviour class

Renders bubbles on an AnimatedBackground.

Inheritance

Constructors

BubblesBehaviour({BubbleOptions options = const BubbleOptions(), dynamic onPop(bool wasTap)?})
Creates a new bubbles behaviour.

Properties

bubbles ↔ List<Bubble>?
getter/setter pair
deltaTargetRadius ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isInitialized → bool
Gets the initialization state of this behaviour
no setteroverride
onPop ↔ dynamic Function(bool wasTap)?
Called when a bubble pops
getter/setter pair
options ↔ BubbleOptions
Gets the bubbles options used to configure this behaviour.
getter/setter pair
renderObject ↔ RenderAnimatedBackground?
The render object of the AnimatedBackground this behaviour is provided to.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size?
The size of the render object of the AnimatedBackground this behaviour is provided to.
no setterinherited

Methods

builder(BuildContext context, BoxConstraints constraints, Widget child) → Widget
Called when the layout needs to be rebuilt.
override
generateBubbles(int num) → List<Bubble>
Generates an amount of bubbles and initializes them.
init() → void
Called when this behaviour should be initialized
override
initFrom(Behaviour oldBehaviour) → void
Called when this behaviour should be initialized from an old behaviour.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOptionsUpdate(BubbleOptions? oldOptions) → void
Called when the behaviour got new options and should update accordingly.
paint(PaintingContext context, Offset offset) → void
Called each time the AnimatedBackground needs to repaint.
override
tick(double delta, Duration elapsed) → bool
Called each time there is an update from the ticker on the AnimatedBackground
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

random ↔ Random
getter/setter pair

Constants

sqrtInverse → const double