SpaceBehaviour class

Renders a warp field on a AnimatedBackground.

Code inspired by http://www.kevs3d.co.uk/dev/warpfield/

Inheritance
Implementers

Constructors

SpaceBehaviour({Color backgroundColor = const Color(0xFF000000)})

Properties

center ↔ Offset?
The center of the warp field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isInitialized → bool
Gets the initialization state of this behaviour
no setteroverride
renderObject ↔ RenderAnimatedBackground?
The render object of the AnimatedBackground this behaviour is provided to.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size?
The size of the render object of the AnimatedBackground this behaviour is provided to.
no setterinherited
stars ↔ List<Star>?
The list of stars spawned by the behaviour
getter/setter pair
targetCenter ↔ Offset?
The target center of the warp field.
getter/setter pair

Methods

builder(BuildContext context, BoxConstraints constraints, Widget child) → Widget
Called when the layout needs to be rebuilt.
override
init() → void
Called when this behaviour should be initialized
override
initFrom(Behaviour oldBehaviour) → void
Called when this behaviour should be initialized from an old behaviour.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
Called each time the AnimatedBackground needs to repaint.
override
tick(double delta, Duration elapsed) → bool
Called each time there is an update from the ticker on the AnimatedBackground
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

random ↔ Random
getter/setter pair